LockedXmlTraits
===============

.. currentmodule:: wwt_data_formats

.. autoclass:: LockedXmlTraits
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~LockedXmlTraits.apply_to_xml
      ~LockedXmlTraits.from_xml
      ~LockedXmlTraits.to_xml

   .. rubric:: Methods Documentation

   .. automethod:: apply_to_xml
   .. automethod:: from_xml
   .. automethod:: to_xml
